@@ -4,8 +4,8 @@ from gettext import gettext as _
 
 import gobject
 import gnomevfs
-import deskbar.handler
-from deskbar.filewatcher import FileWatcher
+import deskbar.Handler
+from deskbar.Watcher import FileWatcher
 
 HANDLERS = {
 	"GtkBookmarkHandler" : {
@@ -16,23 +16,26 @@ HANDLERS = {
 
 GTK_BOOKMARKS_FILE = expanduser("~/.gtk-bookmarks")
 
-class GtkBookmarkMatch(deskbar.handler.Match):
-	def __init__(self, backend, name, path):
-		deskbar.handler.Match.__init__(self, backend, name)
-		self._path = path
+class GtkBookmarkMatch(deskbar.Match.Match):
+	def __init__(self, backend, name=None, path=None, **args):
+		deskbar.Match.Match.__init__(self, backend, name=name, **args)
+		self.path = path
 		
 	def action(self, text=None):
-		gobject.spawn_async(["nautilus", self._path], flags=gobject.SPAWN_SEARCH_PATH)
+		gobject.spawn_async(["nautilus", self.path], flags=gobject.SPAWN_SEARCH_PATH)
+		
+	def get_category(self):
+		return "places"
 	
 	def get_verb(self):
 		return _("Open location %s") % "<b>%(name)s</b>"
 	
 	def get_hash(self, text=None):
-		return self._path
+		return self.path
 	
-class GtkBookmarkHandler(deskbar.handler.Handler):
+class GtkBookmarkHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "folder-bookmark.png")
+		deskbar.Handler.Handler.__init__(self, "folder-bookmark.png")
 		self._locations = {}
 		
 	def initialize(self):
@@ -43,14 +46,14 @@ class GtkBookmarkHandler(deskbar.handler.Handler):
 		self.watcher.add(GTK_BOOKMARKS_FILE)
 		self._scan_bookmarks_files()
 		
-	def query(self, query, max=5):
+	def query(self, query):
 		result = []
 		query = query.lower()
 		for bmk, (name, loc) in self._locations.items():
 			if bmk.startswith(query):
 				result.append(GtkBookmarkMatch(self, name, loc))
 		
-		return result[:max]
+		return result
 	
 	def stop(self):
 		self.watcher.remove(GTK_BOOKMARKS_FILE)
