@@ -15,6 +15,8 @@ class CuemiacHistoryView (gtk.TreeView):
 		gtk.TreeView.__init__ (self, SortedDeskbarHistory())
 				
 		icon = gtk.CellRendererPixbuf ()
+		icon.set_property("xpad", 4)
+		icon.set_property("xalign", 0.1)
 		title = gtk.CellRendererText ()
 		title.set_property ("ellipsize", pango.ELLIPSIZE_END)
 		title.set_property ("width-chars", 50) #FIXME: Pick width according to screen size
@@ -25,9 +27,11 @@ class CuemiacHistoryView (gtk.TreeView):
 		hits.set_cell_data_func(icon, self.__get_match_icon_for_cell)
 		self.append_column (hits)
 		
-		self.connect ("row-activated", self.__on_activated)
-		
+		self.connect ("row-activated", lambda w,p,c: self.__on_activated())
+		self.connect ("button-press-event", lambda w,e: self.__on_activated())             
+        
 		self.set_property ("headers-visible", False)
+		self.set_property ("hover-selection", True)
 		
 	def __get_match_icon_for_cell (self, column, cell, model, iter, data=None):
 	
@@ -47,11 +51,12 @@ class CuemiacHistoryView (gtk.TreeView):
 		
 		cell.set_property ("markup", match.get_verb () % verbs)
 
-	def __on_activated (self, treeview, path, column):
+	def __on_activated (self):
 		model, iter = self.get_selection().get_selected()
 		match = model[iter][0]
 		self.emit ("match-selected", match)
-
+		return True
+		
 class CuemiacHistoryPopup (CuemiacAlignedWindow) :
 
 	__gsignals__ = {
