@@ -112,6 +112,10 @@ class CuemiacEntryUI (DeskbarUI):
 		
 		self.applet.set_flags(gtk.CAN_FOCUS)
 	
+	def close_view(self):
+		self.hide_window (self.popup)
+		self.emit ("stop-query")
+		
 	def on_config_width(self, value=None):
 		if value != None and value.type == gconf.VALUE_INT:
 			self.config_width = value.get_int()
@@ -344,6 +348,8 @@ class CuemiacEntryUI (DeskbarUI):
 		if iter is None:
 			# No selection, select top element # FIXME do this
 			iter = self.model.get_iter_first()
+			if iter == None:
+				return
 			while (not self.model.iter_has_child(iter)) or (not self.cview.row_expanded(self.model.get_path(iter))):
 				iter = self.model.iter_next(iter)
 			iter = self.model.iter_children(iter)
